@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: language-javascript
 version: 0.6.0.4
-id: language-javascript-0.6.0.4-c43c009634450c277e20aa280373fe2a
-key: langu_7CzyKWKjonl7ya7tocJK4R
+id: language-javascript-0.6.0.4-2135c0dc17d49d03d59acceac4216f0a
+key: langu_I2zwlRUKdQ76jWmlj0dHzd
 license: BSD3
 copyright: (c) 2010-2015 Alan Zimmerman, 2015 Erik de Castro Lopo
 maintainer: Erik de Castro Lopo <erikd@mega-nerd.com>
@@ -33,11 +33,11 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/language-javascript-0.6.0.4
 library-dirs: /usr/lib/ghc-7.10.3/site-local/language-javascript-0.6.0.4
 data-dir: /usr/share/arm-linux-ghc-7.10.3/language-javascript-0.6.0.4
-hs-libraries: HSlanguage-javascript-0.6.0.4-7CzyKWKjonl7ya7tocJK4R
+hs-libraries: HSlanguage-javascript-0.6.0.4-I2zwlRUKdQ76jWmlj0dHzd
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
+    blaze-builder-0.4.0.2-290873936811c5be5456133d1e8642df
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
